"""
This module contains TunnelLevelObject implementation.

There is no need to import this module directly. Use the methods of
the L{Ruleset object <ruleset.Ruleset>} to create and manipulate
TunnelLevelObjects.

    >>> o = r.object_add("/TunnelLevelObjects/Test")
    >>> o.add(3)
    >>> print o.items
    [3]

@var __revision__: Revision identifier.
"""

__revision__ = '%K%'

import plobject
from thisversion import PLDB
import plutil

OBJECT_TYPE = PLDB.OBJECT_TYPE_TUNNELLVLOBJECT

class TunnelLevelObject(plobject.PLObject):
	"""
	TunnelLevelObject Implementation

	Object path: /TunnelLevelObjects

	@cvar Item: TunnelLevelObject Item implementation.
	"""

	__slots__ = ('_prop', '_pldb', '_callback', '_item_added')

	def __init__(self, **props):
		plobject.PLObject.__init__(self, **props)

	base_path = plutil.roConst("/TunnelLevelObjects", "Only the type portion of the path")
	type = plutil.roConst(OBJECT_TYPE, "Number representing the type of object")

	def _create_item(self, value):
		return self.Item(self, value=value)

	def add(self, value):
		"""
		Adds a TunnelLevelObject item to this TunnelLevelObject.

		@type value: C{int}
		@param value: The value is an integer describing the TunnelLevelObject item.

		@rtype: C{None}
		"""
		plobject.PLObject.add(self, value)


	class Item(plobject.PLObject.Item):
		"""
		TunnelLevelObject Item implementation.
		Should not be instantiated, use L{TunnelLevelObject.add} instead.

		@type value: C{int}
		"""
		__slots__ = ('_prop', '_parent')
		_Prop = plutil.Prop(value=int, *plobject._item_props)

		def __str__(self):
                        return "%s" % self._prop.value

		value = property(lambda self: self._prop.value, doc="Tunnel type ID")
