"""
This module contains ProtocolObject implementation.

There is no need to import this module directly. Use the methods of
the L{Ruleset object <ruleset.Ruleset>} to create and manipulate
ProtocolObjects.

    >>> o = r.object_add("/ProtocolObjects/Test")
    >>> o.add("TCP")
    >>> o.add("17")
    >>> print o.items
    ['6', '17']

@var __revision__: Revision identifier.
"""

__revision__ = '%K%'

import plobject
from thisversion import PLDB
import plutil
from plutil import verify_ip
import socket

def _verify_protocol(protocol_id):
	if protocol_id < 0 or protocol_id > 255:
		return False
	return True

class ProtocolObject(plobject.PLObject):
	"""
	ProtocolObject Implementation

	Object path: /ProtocolObjects

	@cvar Item: ProtocolObject Item implementation.
	"""

	__slots__ = ('_prop', '_pldb', '_callback', '_item_added')
	
	base_path = plutil.roConst("/ProtocolObjects", "Only the type portion of the path")
	type = plutil.roConst(PLDB.OBJECT_TYPE_PROTOCOLOBJECT, "Number representing the type of object")

	def _create_item(self, value):
		# basestring covers both Normal string and unicodestrings
		if isinstance(value, basestring) and not value.isdigit():
			# FIXME Should we use protocols.PROTOCOLS instead of getprotobyname to ensure consistency?
			try:
				item = self.Item(self, protocol=socket.getprotobyname(value))
			except socket.error:
				raise ValueError("Couldn't find that protocol in OS protocoldb")

		else:
			item = self.Item(self, protocol=value)

		if not _verify_protocol(item.protocol):
			raise ValueError("First argument doesn't seem like a Protocol")

		return item

	def add(self, value):
		"""
		Adds a ProtocolObject item to this ProtocolObject.

		@type value: C{str}
		@param value: The value is a string describing the ProtocolObject item.
			The string can be the IP protocol number or a string found in
			your services file. (GRE, TCP etc...)

		"""
		plobject.PLObject.add(self, value)


	class Item(plobject.PLObject.Item):
		"""
		ProtocolObject Item implementation.
		Should not be instantiated, use L{ProtocolObject.add} instead.

		@type protocol: C{int}
		"""
		__slots__ = ('_prop', '_parent')
		_Prop = plutil.Prop(protocol=int, *plobject._item_props)

		def __str__(self):
			return str(self._prop.protocol)

		protocol = property(lambda self: self._prop.protocol, doc="Protocol number.")
